@@ -17,6 +17,8 @@
  * along with Almanah.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
+
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -43,9 +45,7 @@ static void activate (GApplication *application);
 static gint handle_command_line (GApplication *application, GApplicationCommandLine *command_line);
 static void window_removed (GtkApplication *application, GtkWindow *window);
 
-static void almanah_application_init_actions (AlmanahApplication *self);
-
-/* GMenu application actions */
+/* Application actions */
 static void action_search_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void action_preferences_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void action_import_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
@@ -54,6 +54,9 @@ static void action_print_cb (GSimpleAction *action, GVariant *parameter, gpointe
 static void action_about_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void action_quit_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 
+/* Some callbacks */
+void almanah_application_style_provider_parsing_error_cb (GtkCssProvider *provider, GtkCssSection *section, GError *error, gpointer user_data);
+
 struct _AlmanahApplicationPrivate {
 	gboolean debug;
 
@@ -210,6 +213,18 @@ debug_handler (const char *log_domain, GLogLevelFlags log_level, const char *mes
 	}
 }
 
+/* This function is taken from the Gedit code, so thanks guys! */
+static void
+add_accelerator (GtkApplication *app, const gchar *action_name, const gchar *accel)
+{
+	const gchar *vaccels[] = {
+		accel,
+		NULL
+	};
+
+	gtk_application_set_accels_for_action (app, action_name, vaccels);
+}
+
 static void
 startup (GApplication *application)
 {
@@ -217,7 +232,6 @@ startup (GApplication *application)
 	gchar *db_filename;
 	GError *error = NULL;
 	GtkCssProvider *style_provider;
-	gchar *css_path;
 
 	/* Chain up. */
 	G_APPLICATION_CLASS (almanah_application_parent_class)->startup (application);
@@ -235,12 +249,9 @@ startup (GApplication *application)
 
 	/* Open the DB */
 	db_filename = g_build_filename (g_get_user_data_dir (), "diary.db", NULL);
-	priv->storage_manager = almanah_storage_manager_new (db_filename, NULL);
+	priv->storage_manager = almanah_storage_manager_new (db_filename, priv->settings);
 	g_free (db_filename);
 
-	g_settings_bind (priv->settings, "encryption-key", priv->storage_manager, "encryption-key",
-	                 G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_NO_SENSITIVITY);
-
 	if (almanah_storage_manager_connect (priv->storage_manager, &error) == FALSE) {
 		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 		                                            _("Error opening database"));
@@ -265,20 +276,26 @@ startup (GApplication *application)
 
 	priv->page_setup = gtk_page_setup_new ();
 
-	/* Load GMenu application actions */
-	almanah_application_init_actions (ALMANAH_APPLICATION (application));
+	/* Application actions */
+	g_action_map_add_action_entries (G_ACTION_MAP (application), app_entries, G_N_ELEMENTS (app_entries), application);
 
-	css_path = g_build_filename (almanah_get_css_path (), "almanah.css", NULL);
+	/* Application CSS styles */
 	style_provider = gtk_css_provider_new ();
-	if (!gtk_css_provider_load_from_path (style_provider, css_path, NULL)) {
-		/* Error loading the CSS */
-		g_warning (_("Couldn't load the CSS file '%s'. The interface might not be styled correctly"), css_path);
-		g_error_free (error);
-	} else {
-		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (style_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	}
-	g_free (css_path);
+	g_signal_connect (G_OBJECT (style_provider), "parsing-error", G_CALLBACK (almanah_application_style_provider_parsing_error_cb), NULL);
+	gtk_css_provider_load_from_resource (style_provider, "/org/gnome/Almanah/css/almanah.css");
+	gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (style_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	g_object_unref (style_provider);
+
+	/* Shortcuts */
+	add_accelerator(GTK_APPLICATION (application), "win.select-date", "<Primary>D");
+	add_accelerator(GTK_APPLICATION (application), "win.bold", "<Primary>B");
+	add_accelerator(GTK_APPLICATION (application), "win.italic", "<Primary>I");
+	add_accelerator(GTK_APPLICATION (application), "win.underline", "<Primary>U");
+	add_accelerator(GTK_APPLICATION (application), "win.hyperlink", "<Primary>H");
+	add_accelerator(GTK_APPLICATION (application), "win.insert-time", "<Primary>T");
+	add_accelerator(GTK_APPLICATION (application), "win.important", "<Primary>M");
+	add_accelerator(GTK_APPLICATION (application), "win.undo", "<Primary>Z");
+	add_accelerator(GTK_APPLICATION (application), "win.redo", "<Primary><Shift>Z");
 }
 
 /* Nullify our pointer to the main window when it gets destroyed (e.g. when we quit) so that we don't then try
@@ -359,7 +376,7 @@ handle_command_line (GApplication *application, GApplicationCommandLine *command
 }
 
 static void
-storage_manager_disconnected_cb (AlmanahStorageManager *self, const gchar *gpgme_error_message, const gchar *warning_message, GtkApplication *application)
+storage_manager_disconnected_cb (__attribute__ ((unused)) AlmanahStorageManager *storage_manager, const gchar *gpgme_error_message, const gchar *warning_message, GtkApplication *self)
 {
 	if (gpgme_error_message != NULL || warning_message != NULL) {
 		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
@@ -377,7 +394,15 @@ storage_manager_disconnected_cb (AlmanahStorageManager *self, const gchar *gpgme
 	}
 
 	/* Allow the end of the applaction */
-	g_application_release (G_APPLICATION (application));
+	g_application_release (G_APPLICATION (self));
+}
+
+static gboolean
+storage_disconnect_idle_cb (AlmanahStorageManager *storage_manager)
+{
+	almanah_storage_manager_disconnect (storage_manager, NULL);
+
+	return FALSE;
 }
 
 static void
@@ -394,52 +419,12 @@ window_removed (GtkApplication *application, GtkWindow *window)
 		g_application_hold (G_APPLICATION (application));
 
 		g_signal_connect (priv->storage_manager, "disconnected", (GCallback) storage_manager_disconnected_cb, application);
-		almanah_storage_manager_disconnect (priv->storage_manager, NULL);
+		g_idle_add ((GSourceFunc) storage_disconnect_idle_cb, priv->storage_manager);
 	}
 
 	GTK_APPLICATION_CLASS (almanah_application_parent_class)->window_removed (application, window);
 }
 
-static void
-almanah_application_init_actions (AlmanahApplication *self)
-{
-	GtkBuilder *builder;
-	GError *error = NULL;
-	const gchar *interface_filename = almanah_get_interface_app_menu_filename ();
-
-	g_action_map_add_action_entries (G_ACTION_MAP (self), app_entries, G_N_ELEMENTS (app_entries), self);
-
-	builder = gtk_builder_new ();
-	if (gtk_builder_add_from_file (builder, interface_filename, &error) == FALSE) {
-		/* Show an error */
-		GtkWidget *dialog = gtk_message_dialog_new (NULL,
-							    GTK_DIALOG_MODAL,
-							    GTK_MESSAGE_ERROR,
-							    GTK_BUTTONS_OK,
-							    _("UI file \"%s\" could not be loaded"), interface_filename);
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-
-		g_error_free (error);
-		g_object_unref (builder);
-
-		exit (1);
-	}
-
-	gtk_builder_set_translation_domain (builder, GETTEXT_PACKAGE);
-	gtk_application_set_app_menu (GTK_APPLICATION (self), G_MENU_MODEL (gtk_builder_get_object (builder, "almanah_app_menu")));
-
-#ifndef ENABLE_ENCRYPTION
-#ifndef ENABLE_SPELL_CHECKING
-	/* Remove the "Preferences" entry from the menu */
-	g_action_map_remove_action (G_ACTION_MAP (self), "preferences");
-#endif /* !ENABLE_SPELL_CHECKING */
-#endif /* !ENABLE_ENCRYPTION */
-
-	g_object_unref (builder);
-}
-
 static void
 action_search_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
@@ -458,7 +443,6 @@ action_search_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data
 static void
 action_preferences_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-#if defined(ENABLE_ENCRYPTION) || defined(ENABLE_SPELL_CHECKING)
 	AlmanahApplication *application;
 	GSettings *settings;
 	AlmanahPreferencesDialog *dialog;
@@ -466,13 +450,13 @@ action_preferences_cb (GSimpleAction *action, GVariant *parameter, gpointer user
 	application = ALMANAH_APPLICATION (user_data);
 	settings = almanah_application_dup_settings (application);
 	dialog = almanah_preferences_dialog_new (settings);
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (application->priv->main_window));
 	g_object_unref (settings);
 
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 	gtk_dialog_run (GTK_DIALOG (dialog));
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
-#endif /* ENABLE_ENCRYPTION || ENABLE_SPELL_CHECKING */
 }
 
 static void
@@ -579,7 +563,7 @@ action_about_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 				"license", license,
 				"wrap-license", TRUE,
 				"website-label", _("Almanah Website"),
-				"website", "http://live.gnome.org/Almanah_Diary",
+				"website", PACKAGE_URL,
 				NULL);
 
 	g_free (license);
@@ -600,6 +584,15 @@ action_quit_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 	gtk_widget_destroy (GTK_WIDGET (main_window));
 }
 
+void
+almanah_application_style_provider_parsing_error_cb (__attribute__ ((unused)) GtkCssProvider *provider,
+						     __attribute__ ((unused)) GtkCssSection  *section,
+						     GError         *error,
+						     __attribute__ ((unused)) gpointer        user_data)
+{
+	g_warning (_("Couldn't load the CSS resources. The interface might not be styled correctly: %s"), error->message);
+}
+
 AlmanahApplication *
 almanah_application_new (void)
 {
